@@ -214,7 +214,7 @@ void GlowClientGlobals::readTheme()
 		titleHeight = _theme->buttonSize.height();
 }
 
-bool GlowClientGlobals::reset( unsigned long changed )
+bool GlowClientGlobals::reset( unsigned long /*changed*/ )
 {
 	deletePixmaps();
 	delete _config;
@@ -530,6 +530,12 @@ void GlowClient::mouseDoubleClickEvent( QMouseEvent *e )
 		titlebarDblClickOperation();
 }
 
+void GlowClient::wheelEvent( QWheelEvent *e )
+{
+    if (isSetShade() || QRect( 0, 0, width(), titleHeight ).contains(e->pos()))
+        titlebarMouseWheelOperation( e->delta());
+}
+
 void GlowClient::activeChange()
 {
 	updateButtonPixmaps();
@@ -870,6 +876,9 @@ bool GlowClient::eventFilter( QObject* o, QEvent* e )
 	case QEvent::Show:
 	    showEvent( static_cast< QShowEvent* >( e ));
 	    return true;
+	case QEvent::Wheel:
+	    wheelEvent( static_cast< QWheelEvent* >( e ));
+	    return true;
 	default:
 	    break;
 	}
